@@ -23,7 +23,11 @@ use TYPO3\CMS\Adminpanel\ModuleApi\ModuleDataStorageCollection;
 use TYPO3Fluid\Fluid\Core\ViewHelper\AbstractViewHelper;
 
 /**
- * Render submodule content
+ * ViewHelper to render submodule content.
+ *
+ * ```
+ *   <adm:subModuleRender data="{someData}" module="{someModule}" />
+ * ```
  *
  * @internal
  */
@@ -42,7 +46,7 @@ final class SubModuleRenderViewHelper extends AbstractViewHelper
     {
         $module = $this->arguments['module'];
         $data = $this->arguments['data'];
-        $moduleData = $data->contains($module) ? $data->offsetGet($module) : new ModuleData();
+        $moduleData = $data->offsetExists($module) ? $data->offsetGet($module) : new ModuleData();
         return $module->getContent($moduleData);
     }
 }
