@@ -26,7 +26,6 @@ use TYPO3\CMS\Core\Cache\CacheTag;
 use TYPO3\CMS\Core\Cache\Event\AddCacheTagEvent;
 use TYPO3\CMS\Core\Context\Context;
 use TYPO3\CMS\Core\Context\LanguageAspect;
-use TYPO3\CMS\Core\Context\WorkspaceAspect;
 use TYPO3\CMS\Core\Database\Connection;
 use TYPO3\CMS\Core\Database\ConnectionPool;
 use TYPO3\CMS\Core\Database\Query\QueryBuilder;
@@ -87,7 +86,7 @@ readonly class Typo3DbBackend implements BackendInterface, SingletonInterface
             $connection = $this->connectionPool->getConnectionForTable($tableName);
             $connection->insert($tableName, $fieldValues);
         } catch (DBALException $e) {
-            throw new SqlErrorException($e->getPrevious()->getMessage(), 1470230766, $e);
+            throw new SqlErrorException($e->getMessage(), 1470230766, $e);
         }
 
         $uid = 0;
@@ -121,7 +120,7 @@ readonly class Typo3DbBackend implements BackendInterface, SingletonInterface
             $connection = $this->connectionPool->getConnectionForTable($tableName);
             $connection->update($tableName, $fieldValues, ['uid' => $uid]);
         } catch (DBALException $e) {
-            throw new SqlErrorException($e->getPrevious()->getMessage(), 1470230767, $e);
+            throw new SqlErrorException($e->getMessage(), 1470230767, $e);
         }
 
         if (!$isRelation) {
@@ -164,7 +163,7 @@ readonly class Typo3DbBackend implements BackendInterface, SingletonInterface
         try {
             $this->connectionPool->getConnectionForTable($tableName)->update($tableName, $fieldValues, $where);
         } catch (DBALException $e) {
-            throw new SqlErrorException($e->getPrevious()->getMessage(), 1470230768, $e);
+            throw new SqlErrorException($e->getMessage(), 1470230768, $e);
         }
     }
 
@@ -181,7 +180,7 @@ readonly class Typo3DbBackend implements BackendInterface, SingletonInterface
         try {
             $this->connectionPool->getConnectionForTable($tableName)->delete($tableName, $where);
         } catch (DBALException $e) {
-            throw new SqlErrorException($e->getPrevious()->getMessage(), 1470230769, $e);
+            throw new SqlErrorException($e->getMessage(), 1470230769, $e);
         }
 
         if (!$isRelation && isset($where['uid'])) {
@@ -197,6 +196,10 @@ readonly class Typo3DbBackend implements BackendInterface, SingletonInterface
     public function getObjectDataByQuery(QueryInterface $query): array
     {
         $statement = $query->getStatement();
+        // A custom query is needed for the language, so a custom context is cloned
+        /** @var Context $context */
+        $context = clone GeneralUtility::makeInstance(Context::class);
+        $context->setAspect('language', $query->getQuerySettings()->getLanguageAspect());
         // todo: remove instanceof checks as soon as getStatement() strictly returns Qom\Statement only
         if ($statement instanceof Statement
             && !$statement->getStatement() instanceof QueryBuilder
@@ -220,17 +223,29 @@ readonly class Typo3DbBackend implements BackendInterface, SingletonInterface
                 $queryBuilder->setFirstResult($query->getOffset());
             }
             if ($query->getLimit()) {
-                $queryBuilder->setMaxResults($query->getLimit());
+                // Only set the "real" limit in LIVE workspace, as we do not need to make WS overlays here
+                // And can calculate with the direct result from the RDBMS without needing to calculate this in
+                // PHP (see below).
+                // What we do in workspace, is making a "best guess". Why do we do this? If we have content that
+                // is hidden in a workspace, we need to get the "next" record in line, but we cannot do this
+                // with overlays in SQL. So we use the "best guess" by adding twice the limit. Imagine you have
+                // 2000 news records, and we need to manually calculate the first 10 records, we just take 20 records
+                // from SQL and hope that this matches for "most" usecases (Pareto Principle).
+                if ($context->getAspect('workspace')->isLive()) {
+                    $queryBuilder->setMaxResults($query->getLimit());
+                } else {
+                    $queryBuilder->setMaxResults($query->getLimit() * 2);
+                }
             }
             try {
                 $rows = $queryBuilder->executeQuery()->fetchAllAssociative();
             } catch (DBALException $e) {
-                throw new SqlErrorException($e->getPrevious()->getMessage(), 1472074485, $e);
+                throw new SqlErrorException($e->getMessage(), 1472074485, $e);
             }
         }
 
         if (!empty($rows)) {
-            $rows = $this->overlayLanguageAndWorkspace($query->getSource(), $rows, $query);
+            $rows = $this->overlayLanguageAndWorkspace($query->getSource(), $rows, $query, $context);
             if ($this->autoTagging) {
                 $source = $query->getSource();
                 if ($source instanceof JoinInterface) {
@@ -263,7 +278,7 @@ readonly class Typo3DbBackend implements BackendInterface, SingletonInterface
             try {
                 $result = $realStatement->executeQuery();
             } catch (DBALException $e) {
-                throw new SqlErrorException($e->getPrevious()->getMessage(), 1472064721, $e);
+                throw new SqlErrorException($e->getMessage(), 1472064721, $e);
             }
             $rows = $result->fetchAllAssociative();
             // Prepared Doctrine DBAL statement
@@ -274,7 +289,7 @@ readonly class Typo3DbBackend implements BackendInterface, SingletonInterface
                 }
                 $result = $realStatement->executeQuery();
             } catch (DBALException $e) {
-                throw new SqlErrorException($e->getPrevious()->getMessage(), 1481281404, $e);
+                throw new SqlErrorException($e->getMessage(), 1481281404, $e);
             }
             $rows = $result->fetchAllAssociative();
         } else {
@@ -285,7 +300,7 @@ readonly class Typo3DbBackend implements BackendInterface, SingletonInterface
                 $connection = $this->connectionPool->getConnectionByName(ConnectionPool::DEFAULT_CONNECTION_NAME);
                 $statement = $connection->executeQuery($realStatement, $parameters);
             } catch (DBALException $e) {
-                throw new SqlErrorException($e->getPrevious()->getMessage(), 1472064775, $e);
+                throw new SqlErrorException($e->getMessage(), 1472064775, $e);
             }
 
             $rows = $statement->fetchAllAssociative();
@@ -338,7 +353,7 @@ readonly class Typo3DbBackend implements BackendInterface, SingletonInterface
             try {
                 $count = $queryBuilder->executeQuery()->fetchOne();
             } catch (DBALException $e) {
-                throw new SqlErrorException($e->getPrevious()->getMessage(), 1472074379, $e);
+                throw new SqlErrorException($e->getMessage(), 1472074379, $e);
             }
             if ($query->getOffset()) {
                 $count -= $query->getOffset();
@@ -378,11 +393,12 @@ readonly class Typo3DbBackend implements BackendInterface, SingletonInterface
             // @todo We couple the Backend to the Entity implementation (uid, isClone); changes there breaks this method
             if ($dataMap->isPersistableProperty($propertyName) && $propertyName !== AbstractDomainObject::PROPERTY_UID && $propertyName !== AbstractDomainObject::PROPERTY_PID && $propertyName !== 'isClone') {
                 $propertyValue = $object->_getProperty($propertyName);
-                $fieldName = $dataMap->getColumnMap($propertyName)->getColumnName();
+                $columnMap = $dataMap->getColumnMap($propertyName);
+                $fieldName = $columnMap->getColumnName();
                 if ($propertyValue === null) {
                     $whereClause[] = $queryBuilder->expr()->isNull($fieldName);
                 } else {
-                    $whereClause[] = $queryBuilder->expr()->eq($fieldName, $queryBuilder->createNamedParameter($dataMapper->getPlainValue($propertyValue)));
+                    $whereClause[] = $queryBuilder->expr()->eq($fieldName, $queryBuilder->createNamedParameter($dataMapper->getPlainValue($propertyValue, $columnMap)));
                 }
             }
         }
@@ -400,7 +416,7 @@ readonly class Typo3DbBackend implements BackendInterface, SingletonInterface
             }
             return null;
         } catch (DBALException $e) {
-            throw new SqlErrorException($e->getPrevious()->getMessage(), 1470231748, $e);
+            throw new SqlErrorException($e->getMessage(), 1470231748, $e);
         }
     }
 
@@ -408,31 +424,24 @@ readonly class Typo3DbBackend implements BackendInterface, SingletonInterface
      * Performs workspace and language overlay on the given row array. The language and workspace id is automatically
      * detected (depending on FE or BE context). You can also explicitly set the language/workspace id.
      */
-    protected function overlayLanguageAndWorkspace(SourceInterface $source, array $rows, QueryInterface $query, ?int $workspaceUid = null): array
+    protected function overlayLanguageAndWorkspace(SourceInterface $source, array $rows, QueryInterface $query, Context $context): array
     {
-        // A custom query is needed for the language, so a custom context is cloned
-        $context = clone GeneralUtility::makeInstance(Context::class);
-        $context->setAspect('language', $query->getQuerySettings()->getLanguageAspect());
-        if ($workspaceUid === null) {
-            $workspaceUid = (int)$context->getPropertyFromAspect('workspace', 'id');
-        } else {
-            $context->setAspect('workspace', GeneralUtility::makeInstance(WorkspaceAspect::class, $workspaceUid));
-        }
+        $workspaceUid = (int)$context->getPropertyFromAspect('workspace', 'id');
 
         $pageRepository = GeneralUtility::makeInstance(PageRepository::class, $context);
         if ($source instanceof SelectorInterface) {
             $tableName = $source->getSelectorName();
             $rows = $this->resolveMovedRecordsInWorkspace($tableName, $rows, $workspaceUid);
-            return $this->overlayLanguageAndWorkspaceForSelect($tableName, $rows, $pageRepository, $query);
+            return $this->overlayLanguageAndWorkspaceForSelect($tableName, $rows, $pageRepository, $query, $context);
         }
         if ($source instanceof JoinInterface) {
             $tableName = $source->getRight()->getSelectorName();
             // Special handling of joined select is only needed when doing workspace overlays, which does not happen
             // in live workspace
             if ($workspaceUid === 0) {
-                return $this->overlayLanguageAndWorkspaceForSelect($tableName, $rows, $pageRepository, $query);
+                return $this->overlayLanguageAndWorkspaceForSelect($tableName, $rows, $pageRepository, $query, $context);
             }
-            return $this->overlayLanguageAndWorkspaceForJoinedSelect($tableName, $rows, $pageRepository, $query);
+            return $this->overlayLanguageAndWorkspaceForJoinedSelect($tableName, $rows, $pageRepository, $query, $context);
         }
         // No proper source, so we do not have a table name here
         // we cannot do an overlay and return the original rows instead.
@@ -444,13 +453,25 @@ readonly class Typo3DbBackend implements BackendInterface, SingletonInterface
      *  - overlay workspace
      *  - overlay language of versioned record again
      */
-    protected function overlayLanguageAndWorkspaceForSelect(string $tableName, array $rows, PageRepository $pageRepository, QueryInterface $query): array
+    protected function overlayLanguageAndWorkspaceForSelect(string $tableName, array $rows, PageRepository $pageRepository, QueryInterface $query, Context $context): array
     {
+        $limit = 0;
         $overlaidRows = [];
+        $countOverlaidRows = 0;
+        if ($query->getLimit() && !$context->getAspect('workspace')->isLive()) {
+            $limit = $query->getLimit();
+        }
+
         foreach ($rows as $row) {
             $row = $this->overlayLanguageAndWorkspaceForSingleRecord($tableName, $row, $pageRepository, $query);
             if (is_array($row)) {
                 $overlaidRows[] = $row;
+                $countOverlaidRows++;
+                // We need to calculate the number of overlaid rows manually in PHP
+                // (via the is_array() above), because some overlays do not exist in a Workspace
+                if ($limit === $countOverlaidRows) {
+                    return $overlaidRows;
+                }
             }
         }
         return $overlaidRows;
@@ -463,16 +484,23 @@ readonly class Typo3DbBackend implements BackendInterface, SingletonInterface
      * a record (TCA[$tableName][columns] does not contain all needed information), which is then used to compute
      * a separate subset of the row which can be overlaid properly.
      */
-    protected function overlayLanguageAndWorkspaceForJoinedSelect(string $tableName, array $rows, PageRepository $pageRepository, QueryInterface $query): array
+    protected function overlayLanguageAndWorkspaceForJoinedSelect(string $tableName, array $rows, PageRepository $pageRepository, QueryInterface $query, Context $context): array
     {
         // No valid rows, so this is skipped
         if (!isset($rows[0]['uid'])) {
             return $rows;
         }
+
+        $limit = 0;
+        $overlaidRows = [];
+        $countOverlaidRows = 0;
+        if ($query->getLimit() && !$context->getAspect('workspace')->isLive()) {
+            $limit = $query->getLimit();
+        }
+
         // First, find out the fields that belong to the "main" selected table which is defined by TCA, and take the first
         // record to find out all possible fields in this database table
         $fieldsOfMainTable = $pageRepository->getRawRecord($tableName, (int)$rows[0]['uid']);
-        $overlaidRows = [];
         if (is_array($fieldsOfMainTable)) {
             foreach ($rows as $row) {
                 $mainRow = array_intersect_key($row, $fieldsOfMainTable);
@@ -480,6 +508,12 @@ readonly class Typo3DbBackend implements BackendInterface, SingletonInterface
                 $mainRow = $this->overlayLanguageAndWorkspaceForSingleRecord($tableName, $mainRow, $pageRepository, $query);
                 if (is_array($mainRow)) {
                     $overlaidRows[] = array_replace($joinRow, $mainRow);
+                    $countOverlaidRows++;
+                    // We need to calculate the number of overlaid rows manually in PHP
+                    // (via the is_array() above), because some overlays do not exist in a Workspace
+                    if ($limit === $countOverlaidRows) {
+                        return $overlaidRows;
+                    }
                 }
             }
         }
